@@ -13,7 +13,7 @@ has '_time'      => (is => 'ro', isa => 'Defined', init_arg => 'time',
 
 # XXX Git differentiates between Author and Committer, maybe this would be
 #     a useful distinction for us?
-has 'committer' => (is => 'ro', isa => 'Str');
+has 'committer' => (is => 'ro', isa => 'Str', default => sub { '' });
 has 'added'     => (is => 'ro', isa => 'ArrayOfCommittables', lazy => 1,
                     default => sub { shift->build_added });
 has 'removed'   => (is => 'ro', isa => 'ArrayOfCommittables', lazy => 1,
@@ -28,7 +28,7 @@ has 'revision'  => (is => 'ro', isa => 'Str', required => 1);
 # XXX Probably should also have shortmessage, which can be the "subject"
 #     for VCSes that store that, and the first line of the message for
 #     VCSes that don't.
-has 'message'   => (is => 'ro', isa => 'Str');
+has 'message'   => (is => 'ro', isa => 'Str', default => sub { '' });
 
 # XXX This should really be being enforced by FileContainer, but see the
 #     note there.
@@ -89,8 +89,7 @@ These are all read-only.
 
 =item C<time>
 
-A L<DateTime|VCI::Util/DateTime> representing date and time of this commit,
-in Unix "epoch" format (the number of seconds since January 1, 1970).
+A L<datetime|VCI::Util/DateTime> representing date and time of this commit.
 
 On VCSes that don't understand atomic commits, this will be the time of
 the I<earliest> commited file in this set.
@@ -160,7 +159,12 @@ the version-control system.
 For version-controls systems that don't understand atomic commits, this
 will be some unique identifier generated by VCI. This identifier is
 guaranteed to be stable--that is, you can use it to retrieve this commit
-object from L<VCI::Abstract::Project/get_commit_by_revision>.
+object from L<VCI::Abstract::Project/get_commit>.
+
+Individual C<VCI::VCS> implementations will specify the format of their
+revision IDs, if they are a VCS that doesn't have unique identifiers for
+commits, or if there is any ambiguity about what exactly "revision id"
+means for that VCS.
 
 =item C<message>
 
@@ -181,6 +185,10 @@ Commits out of the Project's History.
 =item C<new>
 
 Takes all L</Accessors> as named parameters. The following fields are
-B<required>: L</time>, L</revision>, and L</project>.
+B<required>: L</time>, L</revision>, and
+L<project|VCI::Abstract::FileContainer/project>.
+
+If L</committer> and L</message> aren't specified, they default to an
+empty string.
 
 =back
\ No newline at end of file
